@@ -24,7 +24,7 @@ test_that(
   "two-sample calc_decision_rules works",
   {
     set.seed(123)
-    skip_on_ci() # I don't know why but this test keeps failing on GitHub Actions testing
+    # skip_on_ci() # I don't know why but this test keeps failing on GitHub Actions testing
     expect_snapshot_output(
       calc_decision_rules(
         n = cbind(c(10, 20), c(10, 20)), 
